@@ -365,7 +365,7 @@ class TestTimestreamLoader_UnitTests:
         loader = TimestreamLoader('test', 'test', mock_session)
 
         # Test no data
-        result = loader._TimestreamLoader__parse_data([], False, False)
+        result = loader._TimestreamLoader__parse_data([], False, False, False)
         assert type(result) == TimestreamLoadResult
         assert str(result)
         assert len(result.invalid_items) == 0
@@ -382,7 +382,8 @@ class TestTimestreamLoader_UnitTests:
         result = loader._TimestreamLoader__parse_data(
             data=[{'integer': 10}, expected_invalid_item],
             upsert=False,
-            ignore_parse_error=False
+            ignore_parse_error=False,
+            is_multi=False
         )
         assert type(result) == TimestreamLoadResult
         assert len(result.invalid_items) == 1
@@ -405,7 +406,7 @@ class TestTimestreamLoader_UnitTests:
         mock_session.assert_expectations()
 
         # Test no item
-        assert loader._TimestreamLoader__parse_item({}, False, False) == []
+        assert loader._TimestreamLoader__parse_item({}, False, False, False) == []
 
         # Test parse insert item
         expected_dimensions = TimestreamDimensions({
@@ -419,7 +420,7 @@ class TestTimestreamLoader_UnitTests:
             'list': [10, 20.0],
             'string': 'dimension',
             'none': None
-        }, False, False)
+        }, False, False, False)
         assert len(records) == 3
         assert str(records[0])
 
@@ -453,7 +454,7 @@ class TestTimestreamLoader_UnitTests:
         records = loader._TimestreamLoader__parse_item({
             'Time': 1609459200000,
             'integer': 10
-        }, True, False)
+        }, True, False, False)
         assert len(records) == 1
 
         record = records[0]
@@ -470,13 +471,13 @@ class TestTimestreamLoader_UnitTests:
         with pytest.raises(AssertionError) as e_info:
             loader._TimestreamLoader__parse_item({
                 'unparseable': {'key': 'value'}
-            }, False, False)
+            }, False, False, False)
         assert str(e_info.value) == 'Could not create a record or dimension from type "<class \'dict\'>" at key unparseable'
 
         # Test ignore parse error
         records = loader._TimestreamLoader__parse_item({
             'unparseable': {'key': 'value'}
-        }, False, True)
+        }, False, True, False)
         assert len(records) == 0
 
     @pytest.mark.unit
