@@ -136,7 +136,7 @@ class TimestreamLoader(TimestreamReader):
             return result
 
         # Batch the accepted records by common dimensions
-        self._logger.info('starting batching...')
+        self._logger.info('Starting batching...')
         batches = batch_records(
             result.accepted_records,
             max_batch_size=max_batch_size,
@@ -144,10 +144,14 @@ class TimestreamLoader(TimestreamReader):
         )
         assert isinstance(batches, list) and len(batches) > 0, 'Batches must be a non-empty list'
         assert all(len(b.records) > 0 for b in batches), "Not all batches have records (shouldn't be possible)"
-        self._logger.info('batching complete')
+        self._logger.info('Batching complete')
+
         # Write records in batches to Timestream
         result = TimestreamLoadResult()
-        for b in batches:
+        num_batches = len(batches)
+        for i in range(num_batches):
+            self._logger.info(f'Writing batch {i+1}/{num_batches}')
+            b = batches[i]
             dimensions = b.common_dimensions
             if source:
                 dimensions.add_dimension('source', source, overwrite=True)
@@ -171,7 +175,7 @@ class TimestreamLoader(TimestreamReader):
         capture_time: datetime,
         is_multi: bool
     ) -> tuple:
-        self._logger.info(f'Writing insert records with {len(records)} records')
+        self._logger.debug(f'Writing insert records with {len(records)} records')
         assert capture_time, 'A capture time needs to be provided'
         capture_time_ms = self._dt_to_ms(capture_time)
         accepted_records, rejected_records = records, []
@@ -213,7 +217,7 @@ class TimestreamLoader(TimestreamReader):
         source: str,
         is_multi: bool = False
     ) -> tuple:
-        self._logger.info(f'Writing upsert records with {len(records)} records')
+        self._logger.debug(f'Writing upsert records with {len(records)} records')
         accepted_records, rejected_records = records, []
         try:
             common_att = {
